Draw Function Plots with 'C3.js'
c3plot.function.RdDraws a curve corresponding to a function over the interval [from, to] in an interactive plot using 'C3.js'
Usage
# S3 method for class '`function`'
c3plot(x, from = 0, to = 1, ylab = NULL, ...)c3plot.function.RdDraws a curve corresponding to a function over the interval [from, to] in an interactive plot using 'C3.js'
# S3 method for class '`function`'
c3plot(x, from = 0, to = 1, ylab = NULL, ...)